==> libetherx-0.9.tar.gz: libetherx-0.9/src/etherxd_transport.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Jabber
 *  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 */

#include "etherxd.h"

ehandler etherxd__transports = NULL;

/* this is the callback for socket transports */
void etherxd_transport_onNode(thread t, xmlnode in, int type)
{
    tstream ts = (tstream)(t->data);
    ehandler eh = (ehandler)(ts->data_aux1);
    epacket e;

    log_debug(ZONE,"transport: thread %d and type %d",t,type);

    if(type == XMLSTREAM_ERROR)
    {
        log_error("etherxd","socket connected transport sent illegal XML");
        etherxd__transports = ehandler_list_isolate(etherxd__transports, eh);
        return;
    }

    if(type == XMLSTREAM_CLOSE)
    {
        log_error("etherxd","socket connected transport closed connection");
        etherxd__transports = ehandler_list_isolate(etherxd__transports, eh);
        return;
    }

    if(type == XMLSTREAM_BOUNCE)
    {
        e = epacket_new(xmlnode_dup(in), NULL, NULL, NULL);
        log_error("etherxd","bouncing data intended for trasport %s",e->to);
        epacket_error(e,"delivery failure");
        etherxd_send(e);
        return;
    }

    if(type == XMLSTREAM_NODE)
    {
        e = epacket_new(xmlnode_dup(in), NULL, eh->host, eh->namespace);
        etherxd_send(e);
        ts->flag_aux1++;
    }
}

void etherxd_transport_cleanup(void *arg)
{
    thread t = (thread)arg;
    tstream ts = (tstream)(t->data);
    ehandler eh = (ehandler)(ts->data_aux1);
    ehandler curr;

    log_debug(ZONE,"cleaning up after a transport disconnect");

    /* if we got replaced, don't free the ehandler stuff */
    if(eh->t != t) return;

    etherxd__transports = ehandler_list_isolate(etherxd__transports, eh);
    for(curr = eh->children; curr != NULL; curr = curr->next)
        xmlstream_error(curr->t, "Server Disconnected");

    /* we can't free until all the children referencing us are gone/cleaned up */
    while(eh->children != NULL)
        pth_sleep(1);

    pool_free(eh->p);
}

==> libetherx-1.0pre2.tar.gz: libetherx-1.0pre2/src/etherxd_transport.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Jabber
 *  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 */

#include "etherxd.h"

/* this is the callback for socket transports */
void etherxd_transport_onNode(thread t, xmlnode in, int type)
{
    tstream ts = (tstream)(t->data);
    ehandler eh = (ehandler)(ts->data_aux1);
    epacket e;

    log_debug(ZONE,"transport: thread %d and type %d",t,type);

    if(type == XMLSTREAM_ERROR)
    {
        log_error("etherxd","socket connected transport sent illegal XML");
        etherx__handlers = ehandler_list_isolate(etherx__handlers, eh);
        return;
    }

    if(type == XMLSTREAM_CLOSE)
    {
        log_error("etherxd","socket connected transport closed connection");
        etherx__handlers = ehandler_list_isolate(etherx__handlers, eh);
        return;
    }

    if(type == XMLSTREAM_BOUNCE)
    {
        e = epacket_new(in, NULL, NULL, NULL);
        log_error("etherxd","bouncing data intended for trasport %s",e->to);
        epacket_error(e,"delivery failure");
        etherxd_send(e);
        return;
    }

    if(type == XMLSTREAM_NODE)
    {
        e = epacket_new(in, NULL, eh->host, eh->namespace);
        etherxd_send(e);
        ts->flag_aux1++;
    }
}

void etherxd_transport_cleanup(void *arg)
{
    thread t = (thread)arg;
    tstream ts = (tstream)(t->data);
    ehandler eh = (ehandler)(ts->data_aux1);
    ehandler curr;

    log_debug(ZONE,"cleaning up after a transport disconnect");

    /* if we got replaced, don't free the ehandler stuff */
    if(eh->t != t) return;

    etherx__handlers = ehandler_list_isolate(etherx__handlers, eh);
    for(curr = eh->children; curr != NULL; curr = curr->next)
        xmlstream_error(curr->t, "Server Disconnected");

    /* we can't free until all the children referencing us are gone/cleaned up */
    while(eh->children != NULL)
        pth_sleep(1);

    pool_free(eh->p);
}
